==> vtigercrm-5.1.0.tgz: vtigercrm/modules/Utilities/Currencies.php <==
<?php
/*+**********************************************************************************
 * The contents of this file are subject to the vtiger CRM Public License Version 1.0
 * ("License"); You may not use this file except in compliance with the License
 * The Original Code is:  vtiger CRM Open Source
 * The Initial Developer of the Original Code is vtiger.
 * Portions created by vtiger are Copyright (C) vtiger.
 * All Rights Reserved.
 ************************************************************************************/

$currencies = array(
	'Albania, Leke' => array('ALL' ,'Lek'),
	'Argentina, Pesos' => array('ARS' ,'$'),
	'Aruba, Guilders' => array('AWG' ,'ƒ'),
	'Australia, Dollars' => array('AUD' ,'$'),
	'Azerbaijan, New Manats' => array('AZN' ,'ман'),
	'Bahamas, Dollars' => array('BSD' ,'$'),
	'Bahrain, Dinar'=>array('BHD','BD'),
	'Barbados, Dollars' => array('BBD' ,'$'),
	'Belarus, Rubles' => array('BYR' ,'p.'),
	'Belize, Dollars' => array('BZD' ,'BZ$'),
	'Bermuda, Dollars' => array('BMD' ,'$'),
	'Bolivia, Bolivianos' => array('BOB' ,'$b'),
	'Convertible Marka' => array('BAM' ,'KM'),
	'Botswana, Pulas' => array('BWP' ,'P'),
	'Bulgaria, Leva' => array('BGN' ,'лв'),
	'Brazil, Reais' => array('BRL' ,'R$'),
	'Great Britain Pounds' => array('GBP' ,'£'),
	'Brunei Darussalam, Dollars' => array('BND' ,'$'),
	'Canada, Dollars'=>array('CAD','$'),
	'Cayman Islands, Dollars'=>array('KYD','$'),
	'Chile, Pesos'=>array('CLP','$'),
	'Colombia, Pesos'=>array('COP','$'),
	'Costa Rica, Colón'=>array('CRC','₡'),
	'Croatia, Kuna'=>array('HRK','kn'),
	'Cuba, Pesos'=>array('CUP','₱'),
	'Czech Republic, Koruny'=>array('CZK','Kč'),
	'Denmark, Kroner'=>array('DKK','kr'),
	'Dominican Republic, Pesos'=>array('DOP','RD$'),
	'East Caribbean, Dollars'=>array('XCD','$'),
	'Egypt, Pounds'=>array('EGP','£'),
	'El Salvador, Colones'=>array('SVC','$'),
	'England, Pounds'=>array('GBP','£'),
	'Estonia, Krooni'=>array('EEK','kr'),
	'Euro'=>array('EUR','€'),
	'Falkland Islands, Pounds'=>array('FKP','£'),
	'Fiji, Dollars'=>array('FJD','$'),
	'Ghana, Cedis'=>array('GHC','¢'),
	'Gibraltar, Pounds'=>array('GIP','£'),
	'Guatemala, Quetzales'=>array('GTQ','Q'),
	'Guernsey, Pounds'=>array('GGP','£'),
	'Guyana, Dollars'=>array('GYD','$'),
	'Honduras, Lempiras'=>array('HNL','L'),
	'LvHong Kong, Dollars '=>array('HKD','HK$'),
	'Hungary, Forint'=>array('HUF','Ft'),
	'Iceland, Krona'=>array('ISK','kr'),
	'India, Rupees'=>array('INR','₨'),
	'Indonesia, Rupiahs'=>array('IDR','Rp'),
	'Iran, Rials'=>array('IRR','﷼'),	
	'Isle of Man, Pounds'=>array('IMP','£'),
	'Israel, New Shekels'=>array('ILS','₪'),
	'Jamaica, Dollars'=>array('JMD','J$'),
	'Japan, Yen'=>array('JPY','¥'),
	'Jersey, Pounds'=>array('JEP','£'),
	'Kazakhstan, Tenge'=>array('KZT','лв'),
	'Korea (North), Won'=>array('KPW','₩'),
	'Korea (South), Won'=>array('KRW','₩'),
	'Kyrgyzstan, Soms'=>array('KGS','лв'),
	'Laos, Kips'=>array('LAK','₭'),
	'Latvia, Lati'=>array('LVL','Ls'),
	'Lebanon, Pounds'=>array('LBP','£'),
	'Liberia, Dollars'=>array('LRD','$'),
	'Switzerland Francs'=>array('CHF','CHF'),
	'Lithuania, Litai'=>array('LTL','Lt'),
	'Macedonia, Denars'=>array('MKD','ден'),
	'Malaysia, Ringgits'=>array('MYR','RM'),
	'Mauritius, Rupees'=>array('MUR','₨'),
	'Mexico, Pesos'=>array('MXN','$'),
	'Mongolia, Tugriks'=>array('MNT','₮'),
	'Mozambique, Meticais'=>array('MZN','MT'),
	'Namibia, Dollars'=>array('NAD','$'),
	'Nepal, Rupees'=>array('NPR','₨'),
	'Netherlands Antilles, Guilders'=>array('ANG','ƒ'),
	'New Zealand, Dollars'=>array('NZD','$'),
	'Nicaragua, Cordobas'=>array('NIO','C$'),
	'Nigeria, Nairas'=>array('NGN','₦'),
	'North Korea, Won'=>array('KPW','₩'),
	'Norway, Krone'=>array('NOK','kr'),
	'Oman, Rials'=>array('OMR','﷼'),	
	'Pakistan, Rupees'=>array('PKR','₨'),
	'Panama, Balboa'=>array('PAB','B/.'),
	'Paraguay, Guarani'=>array('PYG','Gs'),
	'Peru, Nuevos Soles'=>array('PEN','S/.'),
	'Philippines, Pesos'=>array('PHP','Php'),
	'Poland, Zlotych'=>array('PLN','zł'),
	'Romania, New Lei'=>array('RON','lei'),
	'Russia, Rubles'=>array('RUB','руб'),
	'Saint Helena, Pounds'=>array('SHP','£'),
	'Saudi Arabia, Riyals'=>array('SAR','﷼'),	
	'Serbia, Dinars'=>array('RSD','Дин.'),
	'Seychelles, Rupees'=>array('SCR','₨'),
	'Singapore, Dollars'=>array('SGD','$'),
	'Solomon Islands, Dollars'=>array('SBD','$'),
	'Somalia, Shillings'=>array('SOS','S'),
	'South Africa, Rand'=>array('ZAR','R'),
	'South Korea, Won'=>array('KRW','₩'),
	'Sri Lanka, Rupees'=>array('LKR','₨'),
	'Sweden, Kronor'=>array('SEK','kr'),
	'Switzerland, Francs'=>array('CHF','CHF'),
	'Suriname, Dollars'=>array('SRD','$'),
	'Syria, Pounds'=>array('SYP','£'),
	'Taiwan, New Dollars'=>array('TWD','NT$'),
	'Thailand, Baht'=>array('THB','฿'),
	'Trinidad and Tobago, Dollars'=>array('TTD','TT$'),
	'Turkey, New Lira'=>array('TRY','YTL'),
	'Turkey, Liras'=>array('TRL','₤'),
	'Tuvalu, Dollars'=>array('TVD','$'),
	'Ukraine, Hryvnia'=>array('UAH','₴'),	
	'United Kingdom, Pounds'=>array('GBP','£'),
	'USA, Dollars' => array('USD' ,'$'),
	'Uruguay, Pesos'=>array('UYU','$U'),
	'Uzbekistan, Sums'=>array('UZS','лв'),
	'Venezuela, Bolivares Fuertes'=>array('VEF','Bs'),
	'Vietnam, Dong'=>array('VND','₫'),
	'Zimbabwe Dollars'=>array('ZWD','Z$'),
	);	
/*
	'China, Yuan Renminbi'=>array('SAR','﷼'),	
	'Afghanistan, Afghanis'=>array('SAR','﷼'),	
	'Cambodia, Riels'=>array('SAR','﷼'),	
*/
?>

==> vtigercrm-5.4.0.tgz: vtigercrm/modules/Utilities/Currencies.php <==
<?php
/*+**********************************************************************************
 * The contents of this file are subject to the vtiger CRM Public License Version 1.0
 * ("License"); You may not use this file except in compliance with the License
 * The Original Code is:  vtiger CRM Open Source
 * The Initial Developer of the Original Code is vtiger.
 * Portions created by vtiger are Copyright (C) vtiger.
 * All Rights Reserved.
 ************************************************************************************/

$currencies = array(
	'Albania, Leke' => array('ALL' ,'Lek'),
	'Argentina, Pesos' => array('ARS' ,'$'),
	'Aruba, Guilders' => array('AWG' ,'ƒ'),
	'Australia, Dollars' => array('AUD' ,'$'),
	'Azerbaijan, New Manats' => array('AZN' ,'ман'),
	'Bahamas, Dollars' => array('BSD' ,'$'),
	'Bahrain, Dinar'=>array('BHD','BD'),
	'Barbados, Dollars' => array('BBD' ,'$'),
	'Belarus, Rubles' => array('BYR' ,'p.'),
	'Belize, Dollars' => array('BZD' ,'BZ$'),
	'Bermuda, Dollars' => array('BMD' ,'$'),
	'Bolivia, Bolivianos' => array('BOB' ,'$b'),
	'China, Yuan Renminbi' => array('CNY', '¥'),
	'Convertible Marka' => array('BAM' ,'KM'),
	'Botswana, Pulas' => array('BWP' ,'P'),
	'Bulgaria, Leva' => array('BGN' ,'лв'),
	'Brazil, Reais' => array('BRL' ,'R$'),
	'Great Britain Pounds' => array('GBP' ,'£'),
	'Brunei Darussalam, Dollars' => array('BND' ,'$'),
	'Canada, Dollars'=>array('CAD','$'),
	'Cayman Islands, Dollars'=>array('KYD','$'),
	'Chile, Pesos'=>array('CLP','$'),
	'Colombia, Pesos'=>array('COP','$'),
	'Costa Rica, Colón'=>array('CRC','₡'),
	'Croatia, Kuna'=>array('HRK','kn'),
	'Cuba, Pesos'=>array('CUP','₱'),
	'Czech Republic, Koruny'=>array('CZK','Kč'),
	'Cyprus, Pounds' => array('CYP', '£'),
	'Denmark, Kroner'=>array('DKK','kr'),
	'Dominican Republic, Pesos'=>array('DOP','RD$'),
	'East Caribbean, Dollars'=>array('XCD','$'),
	'Egypt, Pounds'=>array('EGP','£'),
	'El Salvador, Colón'=>array('SVC','₡'),
	'England, Pounds'=>array('GBP','£'),
	'Estonia, Krooni'=>array('EEK','kr'),
	'Euro'=>array('EUR','€'),
	'Falkland Islands, Pounds'=>array('FKP','£'),
	'Fiji, Dollars'=>array('FJD','$'),
	'Ghana, Cedis'=>array('GHC','¢'),
	'Gibraltar, Pounds'=>array('GIP','£'),
	'Guatemala, Quetzales'=>array('GTQ','Q'),
	'Guernsey, Pounds'=>array('GGP','£'),
	'Guyana, Dollars'=>array('GYD','$'),
	'Honduras, Lempiras'=>array('HNL','L'),
	'LvHong Kong, Dollars '=>array('HKD','HK$'),
	'Hungary, Forint'=>array('HUF','Ft'),
	'Iceland, Krona'=>array('ISK','kr'),
	'India, Rupees'=>array('INR','₨'),
	'Indonesia, Rupiahs'=>array('IDR','Rp'),
	'Iran, Rials'=>array('IRR','﷼'),	
	'Isle of Man, Pounds'=>array('IMP','£'),
	'Israel, New Shekels'=>array('ILS','₪'),
	'Jamaica, Dollars'=>array('JMD','J$'),
	'Japan, Yen'=>array('JPY','¥'),
	'Jersey, Pounds'=>array('JEP','£'),
	'Jordan, Dinar' => array('JOD', 'JOD'),
	'Kazakhstan, Tenge'=>array('KZT','〒'),
	'Kenya, Shilling' => array('KES', 'KES'),
	'Korea (North), Won'=>array('KPW','₩'),
	'Korea (South), Won'=>array('KRW','₩'),
	'Kuwait, Dinar' => array('KWD','KWD'),
	'Kyrgyzstan, Soms'=>array('KGS','лв'),
	'Laos, Kips'=>array('LAK','₭'),
	'Latvia, Lati'=>array('LVL','Ls'),
	'Lebanon, Pounds'=>array('LBP','£'),
	'Liberia, Dollars'=>array('LRD','$'),
	'Switzerland Francs'=>array('CHF','CHF'),
	'Lithuania, Litai'=>array('LTL','Lt'),
	'MADAGASCAR, Malagasy Ariary' => array('MGA', 'MGA'),
	'Macedonia, Denars'=>array('MKD','ден'),
	'Malaysia, Ringgits'=>array('MYR','RM'),
	'Malta, Liri' => array('MTL', '₤'),
	'Mauritius, Rupees'=>array('MUR','₨'),
	'Mexico, Pesos'=>array('MXN','$'),
	'Mongolia, Tugriks'=>array('MNT','₮'),
	'Mozambique, Meticais'=>array('MZN','MT'),
	'Namibia, Dollars'=>array('NAD','$'),
	'Nepal, Rupees'=>array('NPR','₨'),
	'Netherlands Antilles, Guilders'=>array('ANG','ƒ'),
	'New Zealand, Dollars'=>array('NZD','$'),
	'Nicaragua, Cordobas'=>array('NIO','C$'),
	'Nigeria, Nairas'=>array('NGN','₦'),
	'North Korea, Won'=>array('KPW','₩'),
	'Norway, Krone'=>array('NOK','kr'),
	'Oman, Rials'=>array('OMR','﷼'),	
	'Pakistan, Rupees'=>array('PKR','₨'),
	'Panama, Balboa'=>array('PAB','B/.'),
	'Paraguay, Guarani'=>array('PYG','Gs'),
	'Peru, Nuevos Soles'=>array('PEN','S/.'),
	'Philippines, Pesos'=>array('PHP','Php'),
	'Poland, Zlotych'=>array('PLN','zł'),
	'Qatar, Rials' => array('QAR', '﷼'),
	'Romania, New Lei'=>array('RON','lei'),
	'Russia, Rubles'=>array('RUB','руб'),
	'Saint Helena, Pounds'=>array('SHP','£'),
	'Saudi Arabia, Riyals'=>array('SAR','﷼'),	
	'Serbia, Dinars'=>array('RSD','Дин.'),
	'Seychelles, Rupees'=>array('SCR','₨'),
	'Singapore, Dollars'=>array('SGD','$'),
	'Solomon Islands, Dollars'=>array('SBD','$'),
	'Somalia, Shillings'=>array('SOS','S'),
	'South Africa, Rand'=>array('ZAR','R'),
	'South Korea, Won'=>array('KRW','₩'),
	'Sri Lanka, Rupees'=>array('LKR','₨'),
	'Sweden, Kronor'=>array('SEK','kr'),
	'Switzerland, Francs'=>array('CHF','CHF'),
	'Suriname, Dollars'=>array('SRD','$'),
	'Syria, Pounds'=>array('SYP','£'),
	'Taiwan, New Dollars'=>array('TWD','NT$'),
	'Thailand, Baht'=>array('THB','฿'),
	'Trinidad and Tobago, Dollars'=>array('TTD','TT$'),
	'Turkey, New Lira'=>array('TRY','YTL'),
	'Turkey, Liras'=>array('TRL','₤'),
	'Tuvalu, Dollars'=>array('TVD','$'),
	'Ukraine, Hryvnia'=>array('UAH','₴'),
	'United Arab Emirates, Dirham' => array('AED', 'AED'),
	'United Kingdom, Pounds'=>array('GBP','£'),
	'United Republic of Tanzania, Shilling' => array('TZS', 'TZS'),
	'USA, Dollars' => array('USD' ,'$'),
	'Uruguay, Pesos'=>array('UYU','$U'),
	'Uzbekistan, Sums'=>array('UZS','лв'),
	'Venezuela, Bolivares Fuertes'=>array('VEF','Bs'),
	'Vietnam, Dong'=>array('VND','₫'),
	'Zambia, Kwacha' => array('ZMK', 'ZMK'),
	'Yemen, Rials'=>array('YER','﷼'),
	'Zimbabwe Dollars'=>array('ZWD','Z$'),
	'Malawi, Kwacha' => array('MWK', 'MK'),
	'Tunisian, Dinar' => array('TD', 'TD'),
	'Moroccan, Dirham' => array('MAD', 'درهم'),
	);	
/*
	'Afghanistan, Afghanis'=>array('SAR','﷼'),	
	'Cambodia, Riels'=>array('SAR','﷼'),	
*/
?>
